/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.system.domain;

import lombok.Data;
import cn.hutool.core.bean.BeanUtil;
import io.swagger.annotations.ApiModelProperty;
import cn.hutool.core.bean.copier.CopyOptions;
import javax.persistence.*;
import javax.validation.constraints.*;
import java.sql.Timestamp;
import java.math.BigDecimal;
import java.io.Serializable;

/**
* @website https://eladmin.vip
* @description /
* @author author
**/
@Entity
@Data
@Table(name="service_fee")
public class ServiceFee implements Serializable {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "`service_fee_id`")
    @ApiModelProperty(value = "ID")
    private Long serviceFeeId;

    @ManyToOne
    @JoinColumn(name = "user_id")
    @ApiModelProperty(value = "劳务人")
    private User user;

    @Column(name = "`payable_fee`")
    @ApiModelProperty(value = "应发金额")
    private BigDecimal payableFee;

    @Column(name = "`tax`")
    @ApiModelProperty(value = "个人所得税")
    private BigDecimal tax;

    @Column(name = "`paid_fee`")
    @ApiModelProperty(value = "实发金额")
    private BigDecimal paidFee;

    @Column(name = "`fee_source`")
    @ApiModelProperty(value = "资金来源")
    private String feeSource;

    @ManyToOne
    @JoinColumn(name = "approve_user_id")
    @ApiModelProperty(value = "审批人")
    private User approveUser;

    @Column(name = "`service_time`")
    @ApiModelProperty(value = "劳务时间")
    private Timestamp serviceTime;

    @Column(name = "`apply_time`")
    @ApiModelProperty(value = "申请时间")
    private Timestamp applyTime;

    @Column(name = "`remark`")
    @ApiModelProperty(value = "备注")
    private String remark;

    @Column(name = "`create_by`")
    @ApiModelProperty(value = "创建者")
    private String createBy;

    @Column(name = "`update_by`")
    @ApiModelProperty(value = "更新者")
    private String updateBy;

    @Column(name = "`create_time`")
    @ApiModelProperty(value = "创建日期")
    private Timestamp createTime;

    @Column(name = "`update_time`")
    @ApiModelProperty(value = "更新时间")
    private Timestamp updateTime;

    public void copy(ServiceFee source){
        BeanUtil.copyProperties(source,this, CopyOptions.create().setIgnoreNullValue(true));
    }
}
