/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.system.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.system.domain.Project;
import me.zhengjie.modules.system.service.ProjectService;
import me.zhengjie.modules.system.service.dto.ProjectQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import me.zhengjie.utils.PageResult;
import me.zhengjie.modules.system.service.dto.ProjectDto;

/**
* @website https://eladmin.vip
* @author author
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "科研信息管理")
@RequestMapping("/api/project")
public class ProjectController {

    private final ProjectService projectService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('project:list')")
    public void exportProject(HttpServletResponse response, ProjectQueryCriteria criteria) throws IOException {
        projectService.download(projectService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询科研信息")
    @ApiOperation("查询科研信息")
    @PreAuthorize("@el.check('project:list')")
    public ResponseEntity<PageResult<ProjectDto>> queryProject(ProjectQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(projectService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增科研信息")
    @ApiOperation("新增科研信息")
    @PreAuthorize("@el.check('project:add')")
    public ResponseEntity<Object> createProject(@Validated @RequestBody Project resources){
        projectService.create(resources);
        return new ResponseEntity<>(HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改科研信息")
    @ApiOperation("修改科研信息")
    @PreAuthorize("@el.check('project:edit')")
    public ResponseEntity<Object> updateProject(@Validated @RequestBody Project resources){
        projectService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @DeleteMapping
    @Log("删除科研信息")
    @ApiOperation("删除科研信息")
    @PreAuthorize("@el.check('project:del')")
    public ResponseEntity<Object> deleteProject(@RequestBody Long[] ids) {
        projectService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}