/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.system.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.system.domain.Purchase;
import me.zhengjie.modules.system.service.PurchaseService;
import me.zhengjie.modules.system.service.dto.PurchaseQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import me.zhengjie.utils.PageResult;
import me.zhengjie.modules.system.service.dto.PurchaseDto;

/**
* @website https://eladmin.vip
* @author author
* 
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "经费支出管理")
@RequestMapping("/api/purchase")
public class PurchaseController {

    private final PurchaseService purchaseService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('purchase:list')")
    public void exportPurchase(HttpServletResponse response, PurchaseQueryCriteria criteria) throws IOException {
        purchaseService.download(purchaseService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询经费支出")
    @ApiOperation("查询经费支出")
    @PreAuthorize("@el.check('purchase:list')")
    public ResponseEntity<PageResult<PurchaseDto>> queryPurchase(PurchaseQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(purchaseService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增经费支出")
    @ApiOperation("新增经费支出")
    @PreAuthorize("@el.check('purchase:add')")
    public ResponseEntity<Object> createPurchase(@Validated @RequestBody Purchase resources){
        purchaseService.create(resources);
        return new ResponseEntity<>(HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改经费支出")
    @ApiOperation("修改经费支出")
    @PreAuthorize("@el.check('purchase:edit')")
    public ResponseEntity<Object> updatePurchase(@Validated @RequestBody Purchase resources){
        purchaseService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @DeleteMapping
    @Log("删除经费支出")
    @ApiOperation("删除经费支出")
    @PreAuthorize("@el.check('purchase:del')")
    public ResponseEntity<Object> deletePurchase(@RequestBody Long[] ids) {
        purchaseService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}