/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.system.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.system.domain.Reimburse;
import me.zhengjie.modules.system.service.ReimburseService;
import me.zhengjie.modules.system.service.dto.ReimburseQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import me.zhengjie.utils.PageResult;
import me.zhengjie.modules.system.service.dto.ReimburseDto;

/**
* @website https://eladmin.vip
* @author author
* 
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "报销单管理")
@RequestMapping("/api/reimburse")
public class ReimburseController {

    private final ReimburseService reimburseService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('reimburse:list')")
    public void exportReimburse(HttpServletResponse response, ReimburseQueryCriteria criteria) throws IOException {
        reimburseService.download(reimburseService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询报销单")
    @ApiOperation("查询报销单")
    @PreAuthorize("@el.check('reimburse:list')")
    public ResponseEntity<PageResult<ReimburseDto>> queryReimburse(ReimburseQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(reimburseService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增报销单")
    @ApiOperation("新增报销单")
    @PreAuthorize("@el.check('reimburse:add')")
    public ResponseEntity<Object> createReimburse(@Validated @RequestBody Reimburse resources){
        reimburseService.create(resources);
        return new ResponseEntity<>(HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改报销单")
    @ApiOperation("修改报销单")
    @PreAuthorize("@el.check('reimburse:edit')")
    public ResponseEntity<Object> updateReimburse(@Validated @RequestBody Reimburse resources){
        reimburseService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @DeleteMapping
    @Log("删除报销单")
    @ApiOperation("删除报销单")
    @PreAuthorize("@el.check('reimburse:del')")
    public ResponseEntity<Object> deleteReimburse(@RequestBody Long[] ids) {
        reimburseService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}