/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.system.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.system.domain.ServiceFee;
import me.zhengjie.modules.system.service.ServiceFeeService;
import me.zhengjie.modules.system.service.dto.ServiceFeeQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import me.zhengjie.utils.PageResult;
import me.zhengjie.modules.system.service.dto.ServiceFeeDto;

/**
* @website https://eladmin.vip
* @author author
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "劳务费管理")
@RequestMapping("/api/serviceFee")
public class ServiceFeeController {

    private final ServiceFeeService serviceFeeService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('serviceFee:list')")
    public void exportServiceFee(HttpServletResponse response, ServiceFeeQueryCriteria criteria) throws IOException {
        serviceFeeService.download(serviceFeeService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询劳务费")
    @ApiOperation("查询劳务费")
    @PreAuthorize("@el.check('serviceFee:list')")
    public ResponseEntity<PageResult<ServiceFeeDto>> queryServiceFee(ServiceFeeQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(serviceFeeService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增劳务费")
    @ApiOperation("新增劳务费")
    @PreAuthorize("@el.check('serviceFee:add')")
    public ResponseEntity<Object> createServiceFee(@Validated @RequestBody ServiceFee resources){
        serviceFeeService.create(resources);
        return new ResponseEntity<>(HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改劳务费")
    @ApiOperation("修改劳务费")
    @PreAuthorize("@el.check('serviceFee:edit')")
    public ResponseEntity<Object> updateServiceFee(@Validated @RequestBody ServiceFee resources){
        serviceFeeService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @DeleteMapping
    @Log("删除劳务费")
    @ApiOperation("删除劳务费")
    @PreAuthorize("@el.check('serviceFee:del')")
    public ResponseEntity<Object> deleteServiceFee(@RequestBody Long[] ids) {
        serviceFeeService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}