/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.system.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.system.domain.UserBank;
import me.zhengjie.modules.system.service.UserBankService;
import me.zhengjie.modules.system.service.dto.UserBankQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import me.zhengjie.utils.PageResult;
import me.zhengjie.modules.system.service.dto.UserBankDto;

/**
* @website https://eladmin.vip
* @author author
* @date 2023-12-21
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "银行卡信息管理")
@RequestMapping("/api/userBank")
public class UserBankController {

    private final UserBankService userBankService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('userBank:list')")
    public void exportUserBank(HttpServletResponse response, UserBankQueryCriteria criteria) throws IOException {
        userBankService.download(userBankService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询银行卡信息")
    @ApiOperation("查询银行卡信息")
    @PreAuthorize("@el.check('userBank:list')")
    public ResponseEntity<PageResult<UserBankDto>> queryUserBank(UserBankQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(userBankService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增银行卡信息")
    @ApiOperation("新增银行卡信息")
    @PreAuthorize("@el.check('userBank:add')")
    public ResponseEntity<Object> createUserBank(@Validated @RequestBody UserBank resources){
        userBankService.create(resources);
        return new ResponseEntity<>(HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改银行卡信息")
    @ApiOperation("修改银行卡信息")
    @PreAuthorize("@el.check('userBank:edit')")
    public ResponseEntity<Object> updateUserBank(@Validated @RequestBody UserBank resources){
        userBankService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @DeleteMapping
    @Log("删除银行卡信息")
    @ApiOperation("删除银行卡信息")
    @PreAuthorize("@el.check('userBank:del')")
    public ResponseEntity<Object> deleteUserBank(@RequestBody Long[] ids) {
        userBankService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}