/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.system.service.impl;

import me.zhengjie.modules.system.domain.ServiceFee;
import me.zhengjie.utils.ValidationUtil;
import me.zhengjie.utils.FileUtil;
import lombok.RequiredArgsConstructor;
import me.zhengjie.modules.system.repository.ServiceFeeRepository;
import me.zhengjie.modules.system.service.ServiceFeeService;
import me.zhengjie.modules.system.service.dto.ServiceFeeDto;
import me.zhengjie.modules.system.service.dto.ServiceFeeQueryCriteria;
import me.zhengjie.modules.system.service.mapstruct.ServiceFeeMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import me.zhengjie.utils.PageUtil;
import me.zhengjie.utils.QueryHelp;
import java.util.List;
import java.util.Map;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import me.zhengjie.utils.PageResult;

/**
* @website https://eladmin.vip
* @description 服务实现
* @author author
**/
@Service
@RequiredArgsConstructor
public class ServiceFeeServiceImpl implements ServiceFeeService {

    private final ServiceFeeRepository serviceFeeRepository;
    private final ServiceFeeMapper serviceFeeMapper;

    @Override
    public PageResult<ServiceFeeDto> queryAll(ServiceFeeQueryCriteria criteria, Pageable pageable){
        Page<ServiceFee> page = serviceFeeRepository.findAll((root, criteriaQuery, criteriaBuilder) -> QueryHelp.getPredicate(root,criteria,criteriaBuilder),pageable);
        return PageUtil.toPage(page.map(serviceFeeMapper::toDto));
    }

    @Override
    public List<ServiceFeeDto> queryAll(ServiceFeeQueryCriteria criteria){
        return serviceFeeMapper.toDto(serviceFeeRepository.findAll((root, criteriaQuery, criteriaBuilder) -> QueryHelp.getPredicate(root,criteria,criteriaBuilder)));
    }

    @Override
    @Transactional
    public ServiceFeeDto findById(Long serviceFeeId) {
        ServiceFee serviceFee = serviceFeeRepository.findById(serviceFeeId).orElseGet(ServiceFee::new);
        ValidationUtil.isNull(serviceFee.getServiceFeeId(),"ServiceFee","serviceFeeId",serviceFeeId);
        return serviceFeeMapper.toDto(serviceFee);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void create(ServiceFee resources) {
        if (resources.getApproveUser().getId() == null){
            resources.setApproveUser(null);
        }
        serviceFeeRepository.save(resources);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void update(ServiceFee resources) {
        if (resources.getApproveUser().getId() == null){
            resources.setApproveUser(null);
        }
        ServiceFee serviceFee = serviceFeeRepository.findById(resources.getServiceFeeId()).orElseGet(ServiceFee::new);
        ValidationUtil.isNull( serviceFee.getServiceFeeId(),"ServiceFee","id",resources.getServiceFeeId());
        serviceFee.copy(resources);
        serviceFeeRepository.save(serviceFee);
    }

    @Override
    public void deleteAll(Long[] ids) {
        for (Long serviceFeeId : ids) {
            serviceFeeRepository.deleteById(serviceFeeId);
        }
    }

    @Override
    public void download(List<ServiceFeeDto> all, HttpServletResponse response) throws IOException {
        List<Map<String, Object>> list = new ArrayList<>();
        for (ServiceFeeDto serviceFee : all) {
            Map<String,Object> map = new LinkedHashMap<>();
//            map.put("劳务人", serviceFee.getUserId());
            map.put("应发金额", serviceFee.getPayableFee());
            map.put("个人所得税", serviceFee.getTax());
            map.put("实发金额", serviceFee.getPaidFee());
            map.put("资金来源", serviceFee.getFeeSource());
//            map.put("审批人", serviceFee.getApproveUserId());
            map.put("劳务时间", serviceFee.getServiceTime());
            map.put("申请时间", serviceFee.getApplyTime());
            map.put("备注", serviceFee.getRemark());
            map.put("创建者", serviceFee.getCreateBy());
            map.put("更新者", serviceFee.getUpdateBy());
            map.put("创建日期", serviceFee.getCreateTime());
            map.put("更新时间", serviceFee.getUpdateTime());
            list.add(map);
        }
        FileUtil.downloadExcel(list, response);
    }
}